==> dokuwiki_0.0.20050922.orig.tar.gz: dokuwiki-2005-09-22/inc/lang/nl/lang.php <==
<?php
/**
 * dutch language file
 *
 * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
 * @author     François Kooman <fkooman.tuxed.net>
 * @author     Jack van Klaren <dokuwiki@afentoe.xs4all.nl>
 * @author     Riny Heijdendael <riny@heijdendael.nl>
 */
$lang['encoding']   = 'utf-8';
$lang['direction']  = 'ltr';

$lang['btn_edit']   = 'Pagina aanpassen';
$lang['btn_source'] = 'Toon pagina broncode';
$lang['btn_show']   = 'Toon pagina';
$lang['btn_create'] = 'Maak deze pagina aan';
$lang['btn_search'] = 'Zoeken';
$lang['btn_save']   = 'Opslaan';
$lang['btn_preview']= 'Voorbeeld';
$lang['btn_top']    = 'Terug naar boven';
$lang['btn_newer']  = '<< recenter';
$lang['btn_older']  = 'ouder >>';
$lang['btn_revs']   = 'Oude revisies';
$lang['btn_recent'] = 'Recente aanpassingen';
$lang['btn_upload'] = 'Upload';
$lang['btn_cancel'] = 'Annuleren';
$lang['btn_index']  = 'Index';
$lang['btn_secedit']= 'Aanpassen';
$lang['btn_login']  = 'Inloggen';
$lang['btn_logout'] = 'Uitloggen';
$lang['btn_admin']  = 'Beheer';
$lang['btn_update'] = 'Bijwerken';
$lang['btn_delete'] = 'Verwijder';
$lang['btn_back']   = 'Terug';
$lang['btn_backlink']    = 'Referenties';
$lang['btn_backtomedia'] = 'Terug naar Bestand selectie';
$lang['btn_subscribe']   = 'Volg wijzigingen';
$lang['btn_unsubscribe'] = 'Stop volgen wijzigingen';

$lang['loggedinas'] = 'Ingelogd als';
$lang['user']       = 'Gebruikersnaam';
$lang['pass']       = 'Wachtwoord';
$lang['passchk']    = 'nogmaals';
$lang['remember']   = 'Bewaar';
$lang['fullname']   = 'Volledige naam';
$lang['email']      = 'E-mail';
$lang['register']   = 'Registreren';
$lang['badlogin']   = 'Sorry: de gebruikersnaam of het wachtwoord klopt niet.';

$lang['regmissing'] = 'Sorry: je moet alle velden invullen.';
$lang['reguexists'] = 'Sorry: er bestaat al een gebruiker met deze loginnaam.';
$lang['regsuccess'] = 'De gebruiker is aangemaakt. Het wachtwoord is per e-mail verzonden.';
$lang['regsuccess2']= 'De gebruiker is aangemaakt.';
$lang['regmailfail']= 'Het lijkt erop dat het sturen van de wachtwoordmail mislukt is. Neem a.u.b. contact op met de beheerder!';
$lang['regbadmail'] = 'Het opgegeven e-mailadres lijkt ongeldig - als je denkt dat dit niet klopt neem dan contact op met de beheerder.';
$lang['regbadpass'] = 'De twee ingevoerde wachtwoorden zijn niet identiek. Probeer het nog eens.';
$lang['regpwmail']  = 'Je DokuWiki wachtwoord';
$lang['reghere']    = 'Je hebt nog geen account? Vraag er eentje aan';

$lang['txt_upload']   = 'Selecteer een bestand om te uploaden';
$lang['txt_filename'] = 'Vul wiki-naam in (optioneel)';
$lang['txt_overwrt']  = 'Overschrijf bestaand bestand';
$lang['lockedby']     = 'Momenteel in gebruik door';
$lang['lockexpire']   = 'Exclusief gebruiksrecht vervalt op';
$lang['willexpire']   = 'Je exclusieve gebruiksrecht voor het aanpassen van deze pagina verloopt over een minuut.\nOm problemen te voorkomen klik op de Voorbeeld knop om de exclusieve gebruiksrechten te verlengen.';

$lang['notsavedyet'] = 'Er zijn op dit moment wijzigingen die nog niet zijn opgeslagen, deze zullen verloren gaan.\nWeet je zeker dat je wilt doorgaan?';
$lang['rssfailed']   = 'Er is een fout opgetreden bij het ophalen van de feed: ';
$lang['nothingfound']= 'Er werd niets gevonden.';

$lang['mediaselect'] = 'Bestand selectie';
$lang['fileupload']  = 'Bestand upload';
$lang['uploadsucc']  = 'Upload geslaagd';
$lang['uploadfail']  = 'Upload mislukt. Misschien verkeerde permissies?';
$lang['uploadwrong'] = 'Upload mislukt. Deze file-extensie is verboden';
$lang['uploadexist'] = 'Bestand bestaat reeds. Er is niets gewijzigd.';
$lang['deletesucc']  = 'Het bestand "%s" is verwijderd.';
$lang['deletefail']  = '"%s" kan niet worden verwijderd - controleer permissies.';
$lang['mediainuse']  = 'Het bestand "%s" is niet verwijderd - het is nog in gebruik.';
$lang['namespaces']  = 'Namespaces';
$lang['mediafiles']  = 'Beschikbare bestanden in';

$lang['reference']   = 'Referenties voor';
$lang['ref_inuse']   = 'Het bestand kan niet worden verwijderd, omdat het nog in gebruik is op de volgende pagina\'s:';
$lang['ref_hidden']  = 'Enkele referenties staan op pagina\'s waarvoor je geen lees permissie hebt';

$lang['hits']       = 'Hits';
$lang['quickhits']  = 'Overeenkomende pagina namen';
$lang['toc']        = 'Inhoudsopgave';
$lang['current']    = 'huidige';
$lang['yours']      = 'Jouw versie';
$lang['diff']       = 'toon verschillen met huidige revisie';
$lang['line']       = 'Regel';
$lang['breadcrumb'] = 'Pad';
$lang['lastmod']    = 'Laatst gewijzigd';
$lang['by']         = 'door';
$lang['deleted']    = 'verwijderd';
$lang['created']    = 'aangemaakt';
$lang['restored']   = 'oude revisie hersteld';
$lang['summary']    = 'Samenvatting aanpassen';

$lang['mail_newpage'] = 'pagina toegevoegd:';
$lang['mail_changed'] = 'pagina aangepast:';

$lang['nosmblinks'] = 'Linken naar Windows shares werkt alleen in Microsoft Internet Explorer.\nJe kan de link wel kopiëren en plakken.';

$lang['qb_alert']   = 'Voer de tekst in die je wilt opmaken.\nDe tekst wordt toegevoegd aan het eind van het document.';
$lang['qb_bold']    = 'Vette tekst';
$lang['qb_italic']  = 'Cursieve tekst';
$lang['qb_underl']  = 'Onderstreepte tekst';
$lang['qb_strike']  = 'Doorgehaalde tekst';
$lang['qb_code']    = 'Code tekst';
$lang['qb_h1']      = 'Niveau 1 kop';
$lang['qb_h2']      = 'Niveau 2 kop';
$lang['qb_h3']      = 'Niveau 3 kop';
$lang['qb_h4']      = 'Niveau 4 kop';
$lang['qb_h5']      = 'Niveau 5 kop';
$lang['qb_link']    = 'Interne link';
$lang['qb_extlink'] = 'Externe link';
$lang['qb_hr']      = 'Horizontale lijn';
$lang['qb_ol']      = 'Geordende lijst item';
$lang['qb_ul']      = 'Ongeordende lijst item';
$lang['qb_media']   = 'Voeg plaatjes en andere bestanden toe';
$lang['qb_sig']     = 'Handtekening invoegen';

$lang['del_confirm']= 'Dit item verwijderen?';
 
$lang['admin_acl']  = 'Toegangsrechten...';
$lang['admin_register']= 'Nieuwe gebruiker toevoegen...';
 
$lang['acl_group']  = 'Groep';
$lang['acl_user']   = 'Gebruiker';
$lang['acl_perms']  = 'Permissies voor';
$lang['page']       = 'Pagina';
$lang['namespace']  = 'Namespace';
 
$lang['acl_perm1']  = 'Lezen';
$lang['acl_perm2']  = 'Bewerken';
$lang['acl_perm4']  = 'Aanmaken';
$lang['acl_perm8']  = 'Upload';
$lang['acl_perm16'] = 'Verwijder';
$lang['acl_new']    = 'Nieuwe regel toevoegen';

$lang['spell_start'] = 'Controleer spelling';
$lang['spell_stop']  = 'Doorgaan met aanpassen';
$lang['spell_wait']  = 'Even wachten a.u.b...';
$lang['spell_noerr'] = 'Geen fouten gevonden';
$lang['spell_nosug'] = 'Geen suggesties';
$lang['spell_change']= 'Wijzig';

$lang['metaedit']    = 'Edit Metadata';
$lang['metasaveerr'] = 'Writing metadata failed';
$lang['metasaveok']  = 'Metadata saved';
$lang['img_backto']  = 'Terug naar';
$lang['img_title']   = 'Titel';
$lang['img_caption'] = 'Bijschrift';
$lang['img_date']    = 'Datum';
$lang['img_fname']   = 'Bestandsnaam';
$lang['img_fsize']   = 'Grootte';
$lang['img_artist']  = 'Fotograaf';
$lang['img_copyr']   = 'Copyright';
$lang['img_format']  = 'Formaat';
$lang['img_camera']  = 'Camera';
$lang['img_keywords']= 'Trefwoorden';

$lang['subscribe_success']  = '%s toegevoegd aan de lijst voor %s';
$lang['subscribe_error']    = 'Fout bij toevoegen van %s aan de lijst voor %s';
$lang['subscribe_noaddress']= 'Er is geen adres dat overeenkomt met uw login, u kan niet toegevoegd worden aan de lijst';
$lang['unsubscribe_success']= '%s verwijderd van de lijst voor %s';
$lang['unsubscribe_error']  = 'Fout bij verwijderen van %s van de lijst voor %s';

//Setup VIM: ex: et ts=2 enc=utf-8 :

==> dokuwiki_0.0.20060309.orig.tar.gz: dokuwiki-2006-03-09/inc/lang/nl/lang.php <==
<?php
/**
 * dutch language file
 *
 * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
 * @author     François Kooman <fkooman.tuxed.net>
 * @author     Jack van Klaren <dokuwiki@afentoe.xs4all.nl>
 * @author     Riny Heijdendael <riny@heijdendael.nl>
 * @author     Koen Huybrechts <huybkoen@gmail.com>
 */
$lang['encoding']   = 'utf-8';
$lang['direction']  = 'ltr';

$lang['btn_edit']   = 'Pagina aanpassen';
$lang['btn_source'] = 'Toon pagina broncode';
$lang['btn_show']   = 'Toon pagina';
$lang['btn_create'] = 'Maak deze pagina aan';
$lang['btn_search'] = 'Zoeken';
$lang['btn_save']   = 'Opslaan';
$lang['btn_preview']= 'Voorbeeld';
$lang['btn_top']    = 'Terug naar boven';
$lang['btn_newer']  = '<< recenter';
$lang['btn_older']  = 'ouder >>';
$lang['btn_revs']   = 'Oude revisies';
$lang['btn_recent'] = 'Recente aanpassingen';
$lang['btn_upload'] = 'Upload';
$lang['btn_cancel'] = 'Annuleren';
$lang['btn_index']  = 'Index';
$lang['btn_secedit']= 'Aanpassen';
$lang['btn_login']  = 'Inloggen';
$lang['btn_logout'] = 'Uitloggen';
$lang['btn_admin']  = 'Beheer';
$lang['btn_update'] = 'Bijwerken';
$lang['btn_delete'] = 'Verwijder';
$lang['btn_back']   = 'Terug';
$lang['btn_backlink']    = 'Referenties';
$lang['btn_backtomedia'] = 'Terug naar Bestand selectie';
$lang['btn_subscribe']   = 'Volg wijzigingen';
$lang['btn_unsubscribe'] = 'Stop volgen wijzigingen';

$lang['loggedinas'] = 'Ingelogd als';
$lang['user']       = 'Gebruikersnaam';
$lang['pass']       = 'Wachtwoord';
$lang['passchk']    = 'nogmaals';
$lang['remember']   = 'Bewaar';
$lang['fullname']   = 'Volledige naam';
$lang['email']      = 'E-mail';
$lang['register']   = 'Registreren';
$lang['badlogin']   = 'Gebruikersnaam en/of Wachtwoord kloppen niet';
$lang['minoredit']  = 'Kleine wijziging';

$lang['regmissing'] = 'Vul al de velden in';
$lang['reguexists'] = 'Er bestaat al een gebruiker met deze loginnaam.';
$lang['regsuccess'] = 'De gebruiker is aangemaakt. Het wachtwoord is per e-mail verzonden.';
$lang['regsuccess2']= 'De gebruiker is aangemaakt.';
$lang['regmailfail']= 'Het lijkt erop dat het sturen van de wachtwoordmail mislukt is. Neem a.u.b. contact op met de beheerder!';
$lang['regbadmail'] = 'Het opgegeven e-mailadres lijkt ongeldig - als je denkt dat dit niet klopt neem dan contact op met de beheerder.';
$lang['regbadpass'] = 'De twee ingevoerde wachtwoorden zijn niet identiek. Probeer het nog eens.';
$lang['regpwmail']  = 'Je DokuWiki wachtwoord';
$lang['reghere']    = 'Je hebt nog geen account? Vraag er eentje aan';

$lang['txt_upload']   = 'Selecteer een bestand om te uploaden';
$lang['txt_filename'] = 'Vul wiki-naam in (optioneel)';
$lang['txt_overwrt']  = 'Overschrijf bestaand bestand';
$lang['lockedby']     = 'Momenteel in gebruik door';
$lang['lockexpire']   = 'Exclusief gebruiksrecht vervalt op';
$lang['willexpire']   = 'Je exclusieve gebruiksrecht voor het aanpassen van deze pagina verloopt over een minuut.\nOm problemen te voorkomen klik op de Voorbeeld knop om de exclusieve gebruiksrechten te verlengen.';

$lang['notsavedyet'] = 'Er zijn op dit moment wijzigingen die nog niet zijn opgeslagen, deze zullen verloren gaan.\nWeet je zeker dat je wilt doorgaan?';
$lang['rssfailed']   = 'Er is een fout opgetreden bij het ophalen van de feed: ';
$lang['nothingfound']= 'Er werd niets gevonden.';

$lang['mediaselect'] = 'Bestand selectie';
$lang['fileupload']  = 'Bestand upload';
$lang['uploadsucc']  = 'Upload geslaagd';
$lang['uploadfail']  = 'Upload mislukt. Misschien verkeerde permissies?';
$lang['uploadwrong'] = 'Upload mislukt. Deze file-extensie is verboden';
$lang['uploadexist'] = 'Bestand bestaat reeds. Er is niets gewijzigd.';
$lang['deletesucc']  = 'Het bestand "%s" is verwijderd.';
$lang['deletefail']  = '"%s" kan niet worden verwijderd - controleer permissies.';
$lang['mediainuse']  = 'Het bestand "%s" is niet verwijderd - het is nog in gebruik.';
$lang['namespaces']  = 'Namespaces';
$lang['mediafiles']  = 'Beschikbare bestanden in';

$lang['reference']   = 'Referenties voor';
$lang['ref_inuse']   = 'Het bestand kan niet worden verwijderd, omdat het nog in gebruik is op de volgende pagina\'s:';
$lang['ref_hidden']  = 'Enkele referenties staan op pagina\'s waarvoor je geen lees permissie hebt';

$lang['hits']       = 'Hits';
$lang['quickhits']  = 'Overeenkomende pagina namen';
$lang['toc']        = 'Inhoudsopgave';
$lang['current']    = 'huidige';
$lang['yours']      = 'Jouw versie';
$lang['diff']       = 'toon verschillen met huidige revisie';
$lang['line']       = 'Regel';
$lang['breadcrumb'] = 'Pad';
$lang['lastmod']    = 'Laatst gewijzigd';
$lang['by']         = 'door';
$lang['deleted']    = 'verwijderd';
$lang['created']    = 'aangemaakt';
$lang['restored']   = 'oude revisie hersteld';
$lang['summary']    = 'Samenvatting aanpassen';

$lang['mail_newpage'] = 'pagina toegevoegd:';
$lang['mail_changed'] = 'pagina aangepast:';

$lang['nosmblinks'] = 'Linken naar Windows shares werkt alleen in Microsoft Internet Explorer.\nJe kan de link wel kopiëren en plakken.';

$lang['qb_alert']   = 'Voer de tekst in die je wilt opmaken.\nDe tekst wordt toegevoegd aan het eind van het document.';
$lang['qb_bold']    = 'Vette tekst';
$lang['qb_italic']  = 'Cursieve tekst';
$lang['qb_underl']  = 'Onderstreepte tekst';
$lang['qb_strike']  = 'Doorgehaalde tekst';
$lang['qb_code']    = 'Code tekst';
$lang['qb_h1']      = 'Niveau 1 kop';
$lang['qb_h2']      = 'Niveau 2 kop';
$lang['qb_h3']      = 'Niveau 3 kop';
$lang['qb_h4']      = 'Niveau 4 kop';
$lang['qb_h5']      = 'Niveau 5 kop';
$lang['qb_link']    = 'Interne link';
$lang['qb_extlink'] = 'Externe link';
$lang['qb_hr']      = 'Horizontale lijn';
$lang['qb_ol']      = 'Geordende lijst item';
$lang['qb_ul']      = 'Ongeordende lijst item';
$lang['qb_media']   = 'Voeg plaatjes en andere bestanden toe';
$lang['qb_sig']     = 'Handtekening invoegen';

$lang['del_confirm']= 'Dit item verwijderen?';
$lang['admin_register']= 'Nieuwe gebruiker toevoegen';
 
$lang['spell_start'] = 'Controleer spelling';
$lang['spell_stop']  = 'Doorgaan met aanpassen';
$lang['spell_wait']  = 'Even wachten a.u.b...';
$lang['spell_noerr'] = 'Geen fouten gevonden';
$lang['spell_nosug'] = 'Geen suggesties';
$lang['spell_change']= 'Wijzig';

$lang['metaedit']    = 'Edit Metadata';
$lang['metasaveerr'] = 'Writing metadata failed';
$lang['metasaveok']  = 'Metadata saved';
$lang['img_backto']  = 'Terug naar';
$lang['img_title']   = 'Titel';
$lang['img_caption'] = 'Bijschrift';
$lang['img_date']    = 'Datum';
$lang['img_fname']   = 'Bestandsnaam';
$lang['img_fsize']   = 'Grootte';
$lang['img_artist']  = 'Fotograaf';
$lang['img_copyr']   = 'Copyright';
$lang['img_format']  = 'Formaat';
$lang['img_camera']  = 'Camera';
$lang['img_keywords']= 'Trefwoorden';

$lang['subscribe_success']  = '%s toegevoegd aan de lijst voor %s';
$lang['subscribe_error']    = 'Fout bij toevoegen van %s aan de lijst voor %s';
$lang['subscribe_noaddress']= 'Er is geen adres dat overeenkomt met uw login, u kan niet toegevoegd worden aan de lijst';
$lang['unsubscribe_success']= '%s verwijderd van de lijst voor %s';
$lang['unsubscribe_error']  = 'Fout bij verwijderen van %s van de lijst voor %s';

//Setup VIM: ex: et ts=2 enc=utf-8 :
